@@ -3,7 +3,7 @@ import pandas as pd
 import math
 
 
-class AroudasScraper():
+class AroudasScraper:
     '''
     AroudasScraper - scrapes house data from aroudas and returns a dataframe or csv file.
 
@@ -41,7 +41,7 @@ class AroudasScraper():
                 page_numbers.append(page.text)
         max_page = int(page_numbers[-1])
         if self.num_houses > 25:
-            pages_to_scrape = math.ceil(self.num_houses/25)
+            pages_to_scrape = math.ceil(self.num_houses / 25)
         else:
             pages_to_scrape = 1
         if max_page < pages_to_scrape:
@@ -92,7 +92,7 @@ class AroudasScraper():
                     other_attrs = raw.split('\n')
                     i = 0
                     while i in range(len(other_attrs)):
-                        page_data[other_attrs[i]] = other_attrs[i+1]
+                        page_data[other_attrs[i]] = other_attrs[i + 1]
                         i += 2
 
                     energy = page.html.find('span.energy-class-tooltip', first=True)
@@ -107,11 +107,12 @@ class AroudasScraper():
                             page_data[attr[0]] = attr[1]
                 all_data.append(page_data)
             print(f'Page {page_num} of {max_num} completed.')
-        self.results = pd.DataFrame(all_data, columns=['city', 'division', 'description', 'link', 'House No.', 'Flat No.',
-                                                       'Area', 'Price per month', 'Number of rooms ', 'Floor', 'No. of floors',
-                                                       'Build year', 'Building type', 'Heating system', 'energy_class',
-                                                       'Nearest kindergarten', 'Nearest educational institution',
-                                                       'Nearest shop', 'Public transport stop'])
+        self.results = pd.DataFrame(all_data,
+                                    columns=['city', 'division', 'description', 'link', 'House No.', 'Flat No.',
+                                             'Area', 'Price per month', 'Number of rooms ', 'Floor', 'No. of floors',
+                                             'Build year', 'Building type', 'Heating system', 'energy_class',
+                                             'Nearest kindergarten', 'Nearest educational institution',
+                                             'Nearest shop', 'Public transport stop'])
         print(f'{len(all_data)} results scarped!')
         return self.results
 
@@ -139,4 +140,3 @@ class AroudasScraper():
         except Exception as ex:
             print('Unable to scrape due to error')
             raise ex
-
